<?php
/**
 * ȥեݡͥȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: C_CreateController.php,v 1.7 2007/05/15 15:36:58 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class C_CreateController
{
    /**
     * ȥե
     *
     * @access public
     * @param string ץȥǥ쥯ȥ
     * @param string ץꥱ̾
     * @param string ȥե
     */
    function trigger($project_dir, $app_name, $controller_file)
    {
        if (preg_match('/(\\\\|\/)$/', $project_dir)) {
            $project_dir = substr($project_dir, 0, -1);
        }

        $controller_template = SYL_PROJECT_DIR . '/var/skel-templates/controller.php';
        $contents = file_get_contents($controller_template);

        $contents = str_replace('{SYL_DIR}',    SYL_DIR,      $contents);
        $contents = str_replace('{WEBAPP_DIR}', $project_dir, $contents);
        $contents = str_replace('{APP_NAME}',   $app_name,    $contents);

        echo "  creating file {$controller_file}\n"; ob_flush();
        $fp = fopen($controller_file, 'wb');
        fwrite($fp, $contents);
        fclose($fp);
    }
}

?>
